@@ -10,11 +10,11 @@ Device::FTDI - perl extension to talk to FTDI chips
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =cut
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use Carp;
 
@@ -46,6 +46,15 @@ our @EXPORT_OK = qw(
     INTERFACE_B
     INTERFACE_C
     INTERFACE_D
+
+    BITMODE_RESET
+    BITMODE_BITBANG
+    BITMODE_MPSSE
+    BITMODE_SYNCBB
+    BITMODE_MCU
+    BITMODE_OPTO
+    BITMODE_CBUS
+    BITMODE_SYNCFF
 );
 
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
@@ -416,7 +425,7 @@ L<https://github.com/trinitum/perl-Device-FTDI/issues>.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2012 Pavel Shaydo.
+Copyright 2012,2015 Pavel Shaydo.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
